==> hindent-5.3.2-162-x86_64.pkg.tar.zst: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hindent
version:              5.3.2
visibility:           public
id:                   hindent-5.3.2-DtfOO9taLcb2cA77O8nEBP
key:                  hindent-5.3.2-DtfOO9taLcb2cA77O8nEBP
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           mihaimaruseac@gmail.com
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.

    See the Github page for usage\/explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  59be42d825d152b462f481968dc46d64
exposed:              True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.CodeBlock HIndent.Pretty
    HIndent.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hindent-5.3.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hindent-5.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-5.3.2-DtfOO9taLcb2cA77O8nEBP
depends:
    Cabal-3.4.1.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.2 exceptions-0.10.4 filepath-1.4.2.1
    haskell-src-exts-1.23.1-GFTfd8DtCuPFUYOEpvxUwA
    monad-loops-0.4.3-C4VZ1LczQKA9hVl8DS9fX mtl-2.2.2 text-1.2.5.0
    transformers-0.5.6.2 utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    yaml-0.11.8.0-lHUdccmI6a9Bqw9bWyyPx

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-5.3.3-4-x86_64.pkg.tar.zst: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hindent
version:              5.3.3
visibility:           public
id:                   hindent-5.3.3-HnuDAbIJVj82t2j6KvMP23
key:                  hindent-5.3.3-HnuDAbIJVj82t2j6KvMP23
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           mihaimaruseac@gmail.com
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.

    See the Github page for usage\/explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  6c16b635d169db048490f4293fa93b1b
exposed:              True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.CodeBlock HIndent.Pretty
    HIndent.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hindent-5.3.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hindent-5.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-5.3.3-HnuDAbIJVj82t2j6KvMP23
depends:
    Cabal-3.4.1.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.2 exceptions-0.10.4 filepath-1.4.2.1
    haskell-src-exts-1.23.1-I4bJmQ12lJj7SnpyM17gac
    monad-loops-0.4.3-C4VZ1LczQKA9hVl8DS9fX mtl-2.2.2 text-1.2.5.0
    transformers-0.5.6.2 utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    yaml-0.11.8.0-6pF0udcImF6GHfe0CJwu5I

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
